CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
73 lines
1.8 KiB
C++
73 lines
1.8 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include "mem_pools_performance_common.hh"
|
|
|
|
/**
|
|
* @addtogroup stream stream
|
|
* @{
|
|
* @ingroup PerformanceTestStream
|
|
*/
|
|
|
|
class MallocFromPoolAsyncBenchmark : public Benchmark<MallocFromPoolAsyncBenchmark> {
|
|
public:
|
|
void operator()(const size_t array_size) {
|
|
const StreamGuard stream_guard{Streams::created};
|
|
const hipStream_t stream = stream_guard.stream();
|
|
|
|
hipMemPool_t mem_pool{nullptr};
|
|
hipMemPoolProps pool_props = CreateMemPoolProps(0, hipMemHandleTypeNone);
|
|
HIP_CHECK(hipMemPoolCreate(&mem_pool, &pool_props));
|
|
|
|
float* array_ptr{nullptr};
|
|
|
|
TIMED_SECTION_STREAM(kTimerTypeEvent, stream) {
|
|
HIP_CHECK(hipMallocFromPoolAsync(&array_ptr, array_size * sizeof(float), mem_pool, stream));
|
|
}
|
|
|
|
REQUIRE(array_ptr != nullptr);
|
|
|
|
HIP_CHECK(hipFreeAsync(array_ptr, stream));
|
|
HIP_CHECK(hipStreamSynchronize(stream));
|
|
HIP_CHECK(hipMemPoolDestroy(mem_pool));
|
|
}
|
|
};
|
|
|
|
static void RunBenchmark(const size_t array_size) {
|
|
MallocFromPoolAsyncBenchmark benchmark;
|
|
benchmark.AddSectionName(std::to_string(array_size));
|
|
benchmark.Run(array_size);
|
|
}
|
|
|
|
/**
|
|
* Test Description
|
|
* ------------------------
|
|
* - Executes `hipMallocFromPoolAsync`:
|
|
* -# Allocation size:
|
|
* - 4 KB
|
|
* - 4 MB
|
|
* - 16 MB
|
|
* Test source
|
|
* ------------------------
|
|
* - performance/api/stream/hipMallocFromPoolAsync.cc
|
|
* Test requirements
|
|
* ------------------------
|
|
* - Device supports memory pools
|
|
* - HIP_VERSION >= 5.2
|
|
*/
|
|
HIP_TEST_CASE(Performance_hipMallocFromPoolAsync) {
|
|
if (!AreMemPoolsSupported(0)) {
|
|
HIP_SKIP_TEST(HipTest::SkipReason::kMemoryPoolUnsupported);
|
|
}
|
|
size_t array_size = GENERATE(4_KB, 4_MB, 16_MB);
|
|
RunBenchmark(array_size);
|
|
}
|
|
|
|
/**
|
|
* End doxygen group PerformanceTest.
|
|
* @}
|
|
*/
|